#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#




#############################################################################
## vTcl Code to Load Stock Images


if {![info exist vTcl(sourcing)]} {
#############################################################################
## Procedure:  vTcl:rename

proc ::vTcl:rename {name} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    regsub -all "\\." $name "_" ret
    regsub -all "\\-" $ret "_" ret
    regsub -all " " $ret "_" ret
    regsub -all "/" $ret "__" ret
    regsub -all "::" $ret "__" ret

    return [string tolower $ret]
}

#############################################################################
## Procedure:  vTcl:image:create_new_image

proc ::vTcl:image:create_new_image {filename {description {no description}} {type {}} {data {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    # Does the image already exist?
    if {[info exists ::vTcl(images,files)]} {
        if {[lsearch -exact $::vTcl(images,files) $filename] > -1} { return }
    }

    if {![info exists ::vTcl(sourcing)] && [string length $data] > 0} {
        set object [image create  [vTcl:image:get_creation_type $filename]  -data $data]
    } else {
        # Wait a minute... Does the file actually exist?
        if {! [file exists $filename] } {
            # Try current directory
            set script [file dirname [info script]]
            set filename [file join $script [file tail $filename] ]
        }

        if {![file exists $filename]} {
            set description "file not found!"
            ## will add 'broken image' again when img is fixed, for now create empty
            set object [image create photo -width 1 -height 1]
        } else {
            set object [image create  [vTcl:image:get_creation_type $filename]  -file $filename]
        }
    }

    set reference [vTcl:rename $filename]
    set ::vTcl(images,$reference,image)       $object
    set ::vTcl(images,$reference,description) $description
    set ::vTcl(images,$reference,type)        $type
    set ::vTcl(images,filename,$object)       $filename

    lappend ::vTcl(images,files) $filename
    lappend ::vTcl(images,$type) $object

    # return image name in case caller might want it
    return $object
}

#############################################################################
## Procedure:  vTcl:image:get_image

proc ::vTcl:image:get_image {filename} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    set reference [vTcl:rename $filename]

    # Let's do some checking first
    if {![info exists ::vTcl(images,$reference,image)]} {
        # Well, the path may be wrong; in that case check
        # only the filename instead, without the path.

        set imageTail [file tail $filename]

        foreach oneFile $::vTcl(images,files) {
            if {[file tail $oneFile] == $imageTail} {
                set reference [vTcl:rename $oneFile]
                break
            }
        }
    }
    return $::vTcl(images,$reference,image)
}

#############################################################################
## Procedure:  vTcl:image:get_creation_type

proc ::vTcl:image:get_creation_type {filename} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    switch [string tolower [file extension $filename]] {
        .ppm -
        .jpg -
        .bmp -
        .gif    {return photo}
        .xbm    {return bitmap}
        default {return photo}
    }
}

foreach img {


            } {
    eval set _file [lindex $img 0]
    vTcl:image:create_new_image\
        $_file [lindex $img 1] [lindex $img 2] [lindex $img 3]
}

}
#############################################################################
## vTcl Code to Load User Images

catch {package require Img}

foreach img {

        {{[file join / home ag cvs q pics gtk stock_media_play_24.png]} {user image} user {
iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAABGdBTUEAALGP
C/xhBQAAAAZiS0dEAAAAAAAA+UO7fwAAAAlwSFlzAAALEgAACxIB0t1+/AAA
AAd0SU1FB9ICBQ4hJRM5WHgAAAD7SURBVHja7dJBLgRREMbxf6t607zX6cxY
DBcYIRhM2xB3cAwJFtjiCMIVJJxDwnbu4RjPQmY5pqrN7OZbV75fVVKwzIyI
YeYcqIDvNsCKYWYTGAPNooBJWiFm4O72phViBtZi5Prq0o2YARVhf7jH48O9
CzEDIoKK0jRHvDw/mRH7BSqoKqqBrcGA97dXE+K7QIWgggZlo9/n6/MDYJxz
zlMX8wGKhsBqWZJSxeHomJwzRVEUcwGqVBFjJKXE8GA0s9wF1HWNitDrrbO9
s2sqd79p3e26yl1Ap+xwcnrmKrfmAshA/utb/nNB4rd97ptP0rTZ3JxFdi8D
wA8u+j1jR500OgAAAABJRU5ErkJggg==}}
        {{[file join / home ag cvs q pics gtk stock_media_stop_24.png]} {user image} user {
iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAABGdBTUEAALGP
C/xhBQAAAAZiS0dEAOoA6ADjBdVW2wAAAAlwSFlzAAALEgAACxIB0t1+/AAA
AAd0SU1FB9ICBQ4lBtUy7A4AAADRSURBVHja7ZRBDoIwEEUfzBSVIQiJHMDo
1o1H040exdO54RYiuGGloBhpjIk/adJMf+fPn6YDf3wbQUdsCczbvQMuQAw0
Lb+54ytQAuehots2yVurxUMy7RAIAfb7HXmeo6ovKzocjr1nvbfNjPVqRXW9
fvQGT8ur65o8y0YXqAEmUYSqYGZ+HCSJ4ZwjtvgjgdD3P+htUVEsSBIjnv2g
AwCm0wkqgoTB6AIVgIqiqoQiowsEACJCmqY450Zv28b3LCq7iANw8j77hzro
Jf/hBTesbkYa92KKnQAAAABJRU5ErkJggg==}}
        {{[file join / home ag cvs q pics gtk stock_media_previous_24.png]} {user image} user {
iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAABGdBTUEAALGP
C/xhBQAAAAZiS0dEAAAAAAAA+UO7fwAAAAlwSFlzAAALEgAACxIB0t1+/AAA
AAd0SU1FB9ICBQ47C3/Cr2wAAAG5SURBVHja7ZWxbtNQFIa/Y+dG6r3gOhsS
VlKEqKhST0UdIEsfA1qqFIaChFqJ0AVmRKUW5r4Ar9EBeWKrYMnCC1BEGzGF
xochQQTFjmMmhh7Jy/E9/3f+66NjuIyC8DNyN4AF4BowB9SAswKdtZHW91mg
MaDjj6pqgbh2u92zWV3dA7TTea77+2+KAGtjTZxkHfDyKM45oigqupbjp0+2
p3abCwjDkFoYThVff3CflTsrUwGVjFwPoGoMzrlc8cePtojjZZZuL5UGBL8d
WGczxXd3nrG4eItmc5lgPih9RT2AwWBAtWLG89vDztvU6w0ajYWZJibXge/7
9C9+jueP9vZeUJu/Shw30TTFGIMUALIcXGQ5SJKkc3BwSBTVOf16SsUYRAQK
EFmA6wBBcAXP//O61Wq9U9WNzfYWgzSl3+9jrQWRfxvTOWvxvL83iYi8V9WN
h5ttzs97mGoVNzkIhd9guKQ8D9+b7G4EWRWRnST5gLWuNGBYoeD5fmaRiOyq
6g8Refn500lpwBeAVIdTkhci8kpVv4nI27Ir/G6Zbaqqr0dnPs4KqOlkHE0r
UNV1Vb15+Xv9P+MX/iagtGEC9ykAAAAASUVORK5CYII=}}
        {{[file join / home ag cvs q pics gtk stock_media_next_24.png]} {user image} user {
iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAAABGdBTUEAALGP
C/xhBQAAAAZiS0dEAAAAAAAA+UO7fwAAAAlwSFlzAAALEgAACxIB0t1+/AAA
AAd0SU1FB9ICBQ4hArYz7RMAAAF7SURBVHja7ZUxTxRRFIW/efe+XZk3vsxY
LCZsIQUEgmvQpdCN/8FaEmoSoIClRGtoDJa2JPo7TJbGgsofYGtrKIHdZ4Fr
BmRmlqGx4CTTvJw53zvJzX1wrwpJwfkbIAF+lvw7CzwBHgNTQAb8mhS8DgSg
W+Lp/PH8/UII4brJVIBOSiAeYHe3z8HBfmFAKaC/s10FwTlHu92uB5iKY7Y2
N0ohaZqSpWk9gIrQefaU9+/2boKcAjSsxTlXDyAiqCjd7nM+Hn64DvHjBrGL
azZQQVVRtczPzfHl81EecgowHA5pqL1DAxWsCmqV6VaL48FXgJPBYPB97Dm7
OC++ZDVAUWt50GziXMLyixVCCERR9BL4ducGiUuI45iH3ufDI2AGwPsEI6Ze
A+89KkKWPWJhcSkffmWUjZH6Y+rTtDAcQIxBTFQP0Gg2eNV7XRR+OfwBjNRs
8HZ1rfDmwA+AURhhrb31Gu8XbcecepNs0yJ1JzBn4V99un9i/z/9BsrzdS8L
y3+LAAAAAElFTkSuQmCC}}

            } {
    eval set _file [lindex $img 0]
    vTcl:image:create_new_image\
        $_file [lindex $img 1] [lindex $img 2] [lindex $img 3]
}

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top83
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.fra84 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_3_0 $base.fra84
    namespace eval ::widgets::$site_3_0.but88 {
        array set save {-command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but90 {
        array set save {-command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but91 {
        array set save {-command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but92 {
        array set save {-command 1 -image 1 -text 1}
    }
    namespace eval ::widgets::$base.sca87 {
        array set save {-bigincrement 1 -command 1 -from 1 -orient 1 -resolution 1 -showvalue 1 -tickinterval 1 -variable 1}
    }
    namespace eval ::widgets::$base.fra93 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_3_0 $base.fra93
    namespace eval ::widgets::$site_3_0.lab95 {
        array set save {-font 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.lab96 {
        array set save {-justify 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.lab97 {
        array set save {-justify 1 -text 1}
    }
    namespace eval ::widgets::$base.fra83 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra83
    namespace eval ::widgets::$site_3_0.cpd84 {
        array set save {-borderwidth 1 -closeenough 1 -height 1 -insertbackground 1 -selectbackground 1 -selectforeground 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist _TopLevel
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {
if {[info command q] == {}} then { proc q { args } { } }
}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 1x1+0+0; update
    wm maxsize $top 2545 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl.tcl"
    bindtags $top "$top Vtcl.tcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top83 {base} {
    if {$base == ""} {
        set base .top83
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -highlightcolor black 
    wm focusmodel $top passive
    wm geometry $top 545x219; update
    wm maxsize $top 1265 994
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 0 0
    wm deiconify $top
    wm title $top "audio_player"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    frame $top.fra84 \
        -borderwidth 2 -height 120 -width 125 
    vTcl:DefineAlias "$top.fra84" "Frame1" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra84
    button $site_3_0.but88 \
        -command {q audio_player::play_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q pics gtk stock_media_play_24.png]] \
        -text button 
    vTcl:DefineAlias "$site_3_0.but88" "Button1" vTcl:WidgetProc "Toplevel1" 1
    button $site_3_0.but90 \
        -command {q audio_player::stop_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q pics gtk stock_media_stop_24.png]] \
        -text button 
    vTcl:DefineAlias "$site_3_0.but90" "Button2" vTcl:WidgetProc "Toplevel1" 1
    button $site_3_0.but91 \
        -command {q audio_player::start_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q pics gtk stock_media_previous_24.png]] \
        -text button 
    vTcl:DefineAlias "$site_3_0.but91" "Button3" vTcl:WidgetProc "Toplevel1" 1
    button $site_3_0.but92 \
        -command {q audio_player::end_cb} \
        -image [vTcl:image:get_image [file join / home ag cvs q pics gtk stock_media_next_24.png]] \
        -text button 
    vTcl:DefineAlias "$site_3_0.but92" "Button4" vTcl:WidgetProc "Toplevel1" 1
    grid $site_3_0.but88 \
        -in $site_3_0 -column 0 -row 0 -columnspan 1 -rowspan 1 
    grid $site_3_0.but90 \
        -in $site_3_0 -column 1 -row 0 -columnspan 1 -rowspan 1 
    grid $site_3_0.but91 \
        -in $site_3_0 -column 0 -row 1 -columnspan 1 -rowspan 1 
    grid $site_3_0.but92 \
        -in $site_3_0 -column 1 -row 1 -columnspan 1 -rowspan 1 
    scale $top.sca87 \
        -bigincrement 0.0 -command {q audio_player::pos_cb} -from 0.0 \
        -orient horizontal -resolution 0.1 -showvalue 0 -tickinterval 0.0 \
        -variable pos 
    vTcl:DefineAlias "$top.sca87" "Scale1" vTcl:WidgetProc "Toplevel1" 1
    frame $top.fra93 \
        -borderwidth 2 -height 89 -width 125 
    vTcl:DefineAlias "$top.fra93" "Frame2" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra93
    label $site_3_0.lab95 \
        -font {Helvetica -14 bold} -text Q-GGI 
    vTcl:DefineAlias "$site_3_0.lab95" "Label1" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.lab96 \
        -justify left -text Audio 
    vTcl:DefineAlias "$site_3_0.lab96" "Label2" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.lab97 \
        -justify left -text Player 
    vTcl:DefineAlias "$site_3_0.lab97" "Label3" vTcl:WidgetProc "Toplevel1" 1
    grid $site_3_0.lab95 \
        -in $site_3_0 -column 0 -row 0 -columnspan 1 -rowspan 1 
    grid $site_3_0.lab96 \
        -in $site_3_0 -column 0 -row 1 -columnspan 1 -rowspan 1 
    grid $site_3_0.lab97 \
        -in $site_3_0 -column 0 -row 2 -columnspan 1 -rowspan 1 
    frame $top.fra83 \
        -borderwidth 2 -relief sunken -height 61 -width 94 
    vTcl:DefineAlias "$top.fra83" "Frame3" vTcl:WidgetProc "Toplevel1" 1
    bind $top.fra83 <Expose> {
        # TODO: your event handler here
q audio_player::expose_cb %c
    }
    set site_3_0 $top.fra83
    canvas $site_3_0.cpd84 \
        -borderwidth 2 -closeenough 1.0 -height 182 -insertbackground black \
        -selectbackground #c4c4c4 -selectforeground black -width 461 
    vTcl:DefineAlias "$site_3_0.cpd84" "Canvas1" vTcl:WidgetProc "Toplevel1" 1
    grid $site_3_0.cpd84 \
        -in $site_3_0 -column 0 -row 0 -columnspan 1 -rowspan 1 
    ###################
    # SETTING GEOMETRY
    ###################
    grid $top.fra84 \
        -in $top -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky s 
    grid $top.sca87 \
        -in $top -column 0 -row 2 -columnspan 2 -rowspan 1 -sticky ew 
    grid $top.fra93 \
        -in $top -column 0 -row 0 -columnspan 1 -rowspan 1 -sticky n 
    grid $top.fra83 \
        -in $top -column 1 -row 0 -columnspan 1 -rowspan 2 -padx 2 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}

Window show .
Window show .top83

main $argc $argv
