
/* sndfile.q: audio file interface 05-13-03 AG
   $Id: sndfile.q,v 1.3 2004/09/23 19:27:46 agraef Exp $ */

/* This file is part of the Q programming system.

   The Q programming system is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   The Q programming system is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

/* This module allows you to access sound files in various formats using Erik
   de Castro Lopo's libsndfile library. Requires libsndfile 1.0 or later. See
   http://www.mega-nerd.com/libsndfile/ for more information. */

import clib;

/* Manifest constants. */

public var

  /* sf_open modes. */

  SFM_READ, SFM_WRITE, SFM_RDWR,

  /* Supported file formats; these are or'ed together from the major formats,
     the subtypes and the endian-ness options. Used in the INFO parameter of
     sf_open when creating a new file. */

  /* Major formats. */

  SF_FORMAT_WAV,	/* Microsoft WAV format (little endian). */
  SF_FORMAT_AIFF,	/* Apple/SGI AIFF format (big endian). */
  SF_FORMAT_AU,		/* Sun/NeXT AU format (big endian). */
  SF_FORMAT_RAW,	/* RAW PCM data. */
  SF_FORMAT_PAF,	/* Ensoniq PARIS file format. */
  SF_FORMAT_SVX,	/* Amiga IFF / SVX8 / SV16 format. */
  SF_FORMAT_NIST,	/* Sphere NIST format. */
  SF_FORMAT_VOC,	/* VOC files. */
  SF_FORMAT_IRCAM,	/* Berkeley/IRCAM/CARL */
  SF_FORMAT_W64,	/* Sonic Foundry's 64 bit RIFF/WAV */
          
  /* Subtypes from here on. */
      
  SF_FORMAT_PCM_S8,	/* Signed 8 bit data */
  SF_FORMAT_PCM_16,	/* Signed 16 bit data */
  SF_FORMAT_PCM_24,	/* Signed 24 bit data */
  SF_FORMAT_PCM_32,	/* Signed 32 bit data */
      
  SF_FORMAT_PCM_U8,	/* Unsigned 8 bit data (WAV and RAW only) */
      
  SF_FORMAT_FLOAT,	/* 32 bit float data */
  SF_FORMAT_DOUBLE,	/* 64 bit float data */
      
  SF_FORMAT_ULAW,	/* U-Law encoded. */
  SF_FORMAT_ALAW,	/* A-Law encoded. */
  SF_FORMAT_IMA_ADPCM,	/* IMA ADPCM. */
  SF_FORMAT_MS_ADPCM,	/* Microsoft ADPCM. */

  SF_FORMAT_GSM610,	/* GSM 6.10 encoding. */
      
  SF_FORMAT_G721_32,	/* 32kbs G721 ADPCM encoding. */
  SF_FORMAT_G723_24,	/* 24kbs G723 ADPCM encoding. */
  SF_FORMAT_G723_40,	/* 40kbs G723 ADPCM encoding. */
      
  SF_FORMAT_DWVW_12,	/* 12 bit Delta Width Variable Word encoding. */
  SF_FORMAT_DWVW_16,	/* 16 bit Delta Width Variable Word encoding. */
  SF_FORMAT_DWVW_24,	/* 24 bit Delta Width Variable Word encoding. */
  SF_FORMAT_DWVW_N,	/* N bit Delta Width Variable Word encoding. */

  /* Endian-ness options. */
      
  SF_ENDIAN_FILE,	/* Default file endian-ness. */
  SF_ENDIAN_LITTLE,	/* Force little endian-ness. */
  SF_ENDIAN_BIG,	/* Force big endian-ness. */
  SF_ENDIAN_CPU,	/* Force CPU endian-ness. */
  
  /* Masks for the different parts of the format specification. */

  SF_FORMAT_SUBMASK,
  SF_FORMAT_TYPEMASK,
  SF_FORMAT_ENDMASK,

  /* sf_command codes. */
  SFC_GET_LOG_INFO,
  SFC_CALC_SIGNAL_MAX,
  SFC_CALC_NORM_SIGNAL_MAX,
  SFC_CALC_MAX_ALL_CHANNELS,
  SFC_CALC_NORM_MAX_ALL_CHANNELS,
  SFC_SET_NORM_FLOAT,
  SFC_SET_NORM_DOUBLE,
  SFC_GET_NORM_FLOAT,
  SFC_GET_NORM_DOUBLE,
  SFC_SET_ADD_PEAK_CHUNK,
  SFC_SET_UPDATE_HEADER_AUTO,
  SFC_UPDATE_HEADER_NOW,
  SFC_FILE_TRUNCATE;

private extern sndfile_vars;

def (SFM_READ, SFM_WRITE, SFM_RDWR,

     SF_FORMAT_WAV,
     SF_FORMAT_AIFF,
     SF_FORMAT_AU,
     SF_FORMAT_RAW,
     SF_FORMAT_PAF,
     SF_FORMAT_SVX,
     SF_FORMAT_NIST,
     SF_FORMAT_VOC,
     SF_FORMAT_IRCAM,
     SF_FORMAT_W64,

     SF_FORMAT_PCM_S8,
     SF_FORMAT_PCM_16,
     SF_FORMAT_PCM_24,
     SF_FORMAT_PCM_32,

     SF_FORMAT_PCM_U8,

     SF_FORMAT_FLOAT,
     SF_FORMAT_DOUBLE,

     SF_FORMAT_ULAW,
     SF_FORMAT_ALAW,
     SF_FORMAT_IMA_ADPCM,
     SF_FORMAT_MS_ADPCM,

     SF_FORMAT_GSM610,

     SF_FORMAT_G721_32,
     SF_FORMAT_G723_24,
     SF_FORMAT_G723_40,

     SF_FORMAT_DWVW_12,
     SF_FORMAT_DWVW_16,
     SF_FORMAT_DWVW_24,
     SF_FORMAT_DWVW_N,

     SF_ENDIAN_FILE,
     SF_ENDIAN_LITTLE,
     SF_ENDIAN_BIG,
     SF_ENDIAN_CPU,

     SF_FORMAT_SUBMASK,
     SF_FORMAT_TYPEMASK,
     SF_FORMAT_ENDMASK,

     SFC_GET_LOG_INFO,
     SFC_CALC_SIGNAL_MAX,
     SFC_CALC_NORM_SIGNAL_MAX,
     SFC_CALC_MAX_ALL_CHANNELS,
     SFC_CALC_NORM_MAX_ALL_CHANNELS,
     SFC_SET_NORM_FLOAT,
     SFC_SET_NORM_DOUBLE,
     SFC_GET_NORM_FLOAT,
     SFC_GET_NORM_DOUBLE,
     SFC_SET_ADD_PEAK_CHUNK,
     SFC_SET_UPDATE_HEADER_AUTO,
     SFC_UPDATE_HEADER_NOW,
     SFC_FILE_TRUNCATE) = sndfile_vars;

/* Library version and error codes. */

public extern sf_version;
public extern sf_perror SF, sf_strerror SF;

/* Supported file formats. The sf_simple_formats functions returns a small
   list of common formats, given as a list of triples (FORMAT, NAME, EXT)
   denoting the numeric code, name and filename extension for each format. The
   sf_major_formats and sf_subtypes functions return all available major
   formats (in the same format as sf_simple_formats) and subtypes (as a list
   of (SUBTYPE, NAME) pairs). */

public extern sf_simple_formats, sf_major_formats, sf_subtypes;

/* SndFile objects. These are returned by sf_open and used by the other
   operations of this module. */

public extern type SndFile;

public is_snd_file X;

is_snd_file _:SndFile		= true;
is_snd_file _			= false otherwise;

/* Opening and closing sound files. When opening a file for writing (or when a
   RAW file is to be read), the INFO parameter must have the form of a triple
   (SAMPLE_RATE, CHANNELS, FORMAT) denoting the sample rate, number of
   channels and the file format, respectively. Otherwise the INFO parameter is
   ignored. Sound files are closed automatically when the corresponding
   SndFile object is garbage-collected. You can also close a file explicitly
   with the sf_close function. */

public extern sf_open NAME MODE INFO;
public extern sf_close SF;

/* Verify that a given INFO tuple is legal. This is useful, in particular, to
   check whether a given format/subtype combination is supported. */

public extern sf_format_check INFO;

/* Number of frames and INFO tuple of a sound file. */

public extern sf_frames SF;
public extern sf_info SF;

/* Reading and writing sound files. The audio data is represented as a raw
   byte string encoding the samples in the selected format (interleaving
   samples for different channels in multichannel formats). All data is
   read/written as a sequence of complete frames. Note that the data is
   converted to/from the target type on the fly.  */

public extern sf_read_short SF NFRAMES;
public extern sf_read_int SF NFRAMES;
public extern sf_read_float SF NFRAMES;
public extern sf_read_double SF NFRAMES;

public extern sf_write_short SF DATA;
public extern sf_write_int SF DATA;
public extern sf_write_float SF DATA;
public extern sf_write_double SF DATA;

/* Position the file pointer at a particular frame. The WHENCE parameter has
   the same meaning as for the lseek function. */

public extern sf_seek SF NFRAMES WHENCE;

/* Command interface. The following operations are supported (see the
   libsndfile documentation of sf_command() for further details):

   sf_command SF SFC_GET_LOG_INFO ()

   sf_command SF SFC_CALC_SIGNAL_MAX ()
   sf_command SF SFC_CALC_NORM_SIGNAL_MAX ()
   sf_command SF SFC_CALC_MAX_ALL_CHANNELS ()
   sf_command SF SFC_CALC_NORM_MAX_ALL_CHANNELS ()

   sf_command SF SFC_SET_NORM_FLOAT FLAG
   sf_command SF SFC_SET_NORM_DOUBLE FLAG

   sf_command SF SFC_GET_NORM_FLOAT ()
   sf_command SF SFC_GET_NORM_DOUBLE ()

   sf_command SF SFC_SET_ADD_PEAK_CHUNK FLAG
   sf_command SF SFC_SET_UPDATE_HEADER_AUTO FLAG

   sf_command SF SFC_UPDATE_HEADER_NOW ()
   sf_command SF SFC_FILE_TRUNCATE NFRAMES

   Most operations either have no parameter (specified as ()), or a FLAG
   argument (either true or false). The SFC_FILE_TRUNCATE operation takes as
   its argument the number of the frame at which the file is to be
   truncated.

   Note that the other functionality of the libsndfile sf_command() routine
   is provided by the sf_version, sf_simple_formats, sf_major_formats and
   sf_subtypes functions, see above. */

public extern sf_command SF CMD ARG;
